@@ -609,7 +609,7 @@ class fillVars(varsShare):
         elif "VMware" in line:
             return "vmware"
         else:
-            return "vesa"
+            return "other"
 
     def get_cl_kernel_uid(self):
         """Get UID of symlink kernel, initramfs and System.map"""
